#
# spec file for package viewnior
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           viewnior
Version:        1.8
Release:        2.7
Summary:        An Image Viewer
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            http://siyanpanayotov.com/project/viewnior/
Source0:        https://github.com/hellosiyan/Viewnior/archive/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM -- Exiv 0.28 support - https://github.com/hellosiyan/Viewnior/pull/130
Patch0:         0001-change-exiv2-AutoPtr-to-unique_ptr.patch
Patch1:         0002-add-support-for-exiv-0.28.0-errors.patch
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.43.0
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(gtk+-2.0)

%description
Viewnior is an image viewer program with a minimal interface.
Its features are:

* Fullscreen & Slideshow
* Rotate, flip, save, delete images
* Animation support
* Browse only selected images
* Navigation window
* Simple interface
* Configurable mouse actions

%lang_package

%prep
%autosetup -p1 -n Viewnior-%{name}-%{version}
# fix spurious executable perms
chmod 0644 AUTHORS COPYING NEWS src/* data/icons/scalable/apps/viewnior.svg

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file -r -G "Elegant Image Viewer" %{name} Graphics Viewer GTK

%files
%license COPYING
%doc AUTHORS NEWS README.md TODO
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/%{name}.metainfo.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man*/%{name}.*

%files lang -f %{name}.lang

%changelog
* Mon Jul 24 2023 Christophe Marin <christophe@krop.fr>
- Add patch to fix build failures with Exiv 0.28:
  * 0001-change-exiv2-AutoPtr-to-unique_ptr.patch
  * 0002-add-support-for-exiv-0.28.0-errors.patch
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8
  * New features included:
  * Add Preview to the Open Image dialog
  * Add "Best Fit" option to the right-click context menu
  * Expand list of image info in the Property window
  * Add hideable statusbar showing the same info as the titlebar
  * Increase size of the Crop Image window
  * Updated translations
  * Fixed:
  * Don't allow drag and drop if source is the viewer itself
  * Better error handling when loading preferences
  * Properly escape file names displayed in the Delete popup
  * Remove 1px white gap when the menu and the toolbar are hidden
  * Memory leaks
- Drop upstream fixed viewnior-appdata_file.patch
* Mon Nov 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build
* Fri May 18 2018 jengelh@inai.de
- Ensure neutrality of description.
* Wed May 16 2018 lazy.kent@opensuse.org
- Update to 1.7.
  * Show image dimensions to title bar.
  * Add option to hide the scrollbars.
  * Wallpaper support for Cinnamon, Puppylinux, and autodetect DE.
  * Fix setting wallpaper on XFCE 4.12+ and MATE.
  * Updated translations.
  * Move to the Meson Build system.
- Add viewnior-appdata_file.patch: fix the appdata.xml file.
- Remove BuildRequires: gnome-common, intltool.
- Add BuildRequires: meson, ninja.
- Correct the source URL.
* Sat Dec 19 2015 lazy.kent@opensuse.org
- Update to 1.6.
  * Added support for the back & forward buttons of your mouse.
  * Updated translations.
  * Fixed mouse scroll behaviour and actions settings.
* Mon May  4 2015 lazy.kent@opensuse.org
- Update to 1.5.
  * Disable Wallpaper support during compilation.
  * Updated translations.
  * Fixed preferences menu position.
  * Nitrogen wallpaper support.
- Corrected the URL and the source URL.
- Drop viewnior-1.4-print.patch: no skill to maintain the patch, and
  it wasn't good enough.
- Drop viewnior-1.4-russian.patch: fixed upstream.
- Replace BuildRequires: libtool -> gnome-common.
- Don't install obsolete ChangeLog (2009).
- No configure, then run autogen.sh.
* Tue Feb 18 2014 lazy.kent@opensuse.org
- Update to 1.4.
  * New features:
    + Read EXIF and IPTC metadata.
    + Nitrogen support.
    + Updated translations.
  * Fixes:
    + Preserve metadata after image modification.
    + Rendidering artifacts when panning.
- Drop viewnior-1.1-ld_fix.patch (no need).
- Rebase viewnior-print.patch.
- Add viewnior-1.4-russian.patch: update Russian translation.
- Add BuildRequire: gcc-c++ pkgconfig(exiv2).
- Correct the source URL.
* Sat Jan  4 2014 lazy.kent@opensuse.org
- Add viewnior-print.patch: add printing support (lp#816563); the
  patch is updated for the current version of Viewnior.
- BuildRequires: libtool.
* Wed Mar 14 2012 lazy.kent@opensuse.org
- Update to 1.3.
  * New features:
    + Wallpaper support for LXDE.
    + Hebrew translation.
  * Fixes:
    + Wallpaper fix for XFCE.
    + Minor fixes.
- Changes in 1.2.
  * New features:
    + Improved menu interface.
    + Wallpaper support for Gnome 2, Gnome 3, XFCE and FluxBox.
    + --fullscreen argument to start in Fullscreen mode.
    + GConf independent.
  * Fixes:
    + Drop images with right click.
    + Save 'Auto resize' option between sessions.
- Split off language package.
- Use full URL as a source.
- Use pkgconfig(*) as build dependencies.
- Removed useless build dependencies (gconf2-devel, gettext,
  shared-mime-info).
- Use make_install macro.
- Added desktop_database_post/un and icon_theme_cache_post/un
  macros.
- Clean up spec.
* Sun Sep 18 2011 andrea@opensuse.org
- added viewnior-1.1-ld_fix.patch to fix failure caused by new ld
* Fri Aug 19 2011 andrea@opensuse.org
- New package
